package com.qmth.distributed.print.upgrade;

import com.qmth.boot.data.upgrade.annotation.DataUpgradeVersion;
import com.qmth.boot.data.upgrade.service.DataUpgradeService;
import com.qmth.boot.data.upgrade.utils.ResourceFileHelper;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.time.DateFormatUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.jdbc.core.JdbcTemplate;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.util.Arrays;
import java.util.Date;
import java.util.StringJoiner;

/**
 * 升级3.4.4后，新版本数据的归档
 */
@DataUpgradeVersion("3.4.5")
public class DataUpgrade_3_4_5 implements DataUpgradeService {

    private static final Logger log = LoggerFactory.getLogger(DataUpgrade_3_4_5.class);

    private static String DATE_PATTERN = "yyyy-MM-dd HH:mm:ss";

    @Override
    public void process(JdbcTemplate jdbcTemplate) {
        log.info("开始处理3.4.5数据库升级脚本；时间：" + DateFormatUtils.format(new Date(), DATE_PATTERN));
        String upgrade_sql1 = "upgrade/3.4.5-upgrade.sql";
        this.execUpgradeSql(jdbcTemplate, upgrade_sql1);
        log.info("结束处理3.4.5数据库升级脚本；时间：" + DateFormatUtils.format(new Date(), DATE_PATTERN));
    }

    private void execUpgradeSql(JdbcTemplate jdbcTemplate, String upgradeSql) {
        if (StringUtils.isBlank(upgradeSql)) {
            throw new RuntimeException("没有配置升级sql脚本文件地址");
        }
        String[] sqlList = StringUtils.split(ResourceFileHelper.readContent(upgradeSql), ";");
        Arrays.stream(sqlList).filter(StringUtils::isNotBlank).forEach(sql -> {
            log.info(sql);
            jdbcTemplate.execute(sql);
        });
    }
}
